Pylinweb
Pylinweb es una biblioteca de pruebas funcionales simple que utiliza Python, Selenium y Chrome driver.
Pre-requisitos
Antes de instalar Pylinweb, asegúrate de tener instalado lo siguiente:
- Python 3.12.2
- Node.js 16.14.0
- JDK 11.0.16.1
Instalación
Puedes instalar Pylinweb usando pip:
pip install pylinweb
Si necesitas una versión específica de Pylinweb, puedes especificarla así:
pip install pylinweb==version
Uso
Una vez instalado, puedes usar Pylinweb con varios argumentos:
| Argumento | Descripción |
|---|---|
| --version | Imprime la versión de Pylinweb. |
| --setup | Copia el directorio de la aplicación e instala las dependencias. |
| --run-tests | Ejecuta las pruebas. |
| --report-html | Genera un informe en html. |
| --report-word | Genera un informe en formato word. |
| --reset | Elimina directorios innecesarios. |
| --open-app | Ejecuta y abre la aplicación del framework |
| --help -h | Muestra la ayuda y explica cómo usar los argumentos. |
Por ejemplo, para imprimir la versión de Pylinweb, puedes usar:
pylinweb --version
Para configurar tu aplicación, puedes usar:
pylinweb --setup
Esto copiará el directorio de la aplicación e instalará las dependencias necesarias.
Para ejecutar las pruebas, debes ubicarte dentro de la carpeta framework_web y ejecutar el siguiente comando:
pylinweb --run-tests
Para generar un informe en allure html, debes ubicarte dentro de la carpeta framework_web y usar este comando:
pylinweb --report-html
Y para generar un informe en formato word, debes ubicarte dentro de la carpeta framework_web y usar este comando:
pylinweb --report-word
Reemplaza version con la versión específica de Pylinweb que deseas instalar.
Metadata
Release files for pylinweb 1.9.6
For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.
Source distribution (sdist)
| File | Size | Uploaded | Provenance | Actions |
|---|---|---|---|---|
| pylinweb-1.9.6.tar.gz | 4.9 kB | Without provenance | Details for pylinweb-1.9.6.tar.gz |
Release files / pylinweb-1.9.6.tar.gz
| Download URL | pylinweb-1.9.6.tar.gz |
|---|---|
| Size | 4.9 kB |
| Tags | Source |
|
SHA-256 checksum How to use checksums |
f0e2cdd3bdf7bdb810f0c6f19ea382f353e1bbac2aa2ccf38977d9aa1321734c
|
|
BLAKE2b-256 checksum How to use checksums |
830648a8d3de60aac505ad17b6685c836d319e842fed349003a5835a1ff0477b
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.1.0 CPython/3.12.2
|
Security for pylinweb 1.9.6
Provenance
Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.
No provenance found
None of the files in this release were uploaded with provenance metadata.
A note on package security
PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.
To learn more about protecting yourself from malicious actors, visit our package security documentation.